@@ -8,11 +8,15 @@ from .base import BaseView
 class PollView(BaseView):
     @classmethod
     async def execute(cls, p: Poll, state: FSMContext = None, **kwargs):
-        pass
+        raise NotImplementedError
+
+    @classmethod
+    async def _execute(cls, p: Poll, state: FSMContext = None, **kwargs):
+        await cls.execute(p, state, **kwargs)
 
     @classmethod
     def register(cls, dp: Dispatcher):
-        callback = cls.execute
+        callback = cls._execute
         kwargs = cls.register_kwargs if cls.register_kwargs else {}
         custom_filters = cls.custom_filters if cls.custom_filters else []
         dp.register_poll_handler(callback, *custom_filters,
